package com.yunfeiyun.agmp.fms.service;

import com.yunfeiyun.agmp.fms.domain.FmsTaskmachine;
import com.yunfeiyun.agmp.fms.domain.reqvo.FmsTaskListReqVo;
import com.yunfeiyun.agmp.fms.domain.resvo.FmsTaskmachineResVo;

import java.util.List;

/**
 * 农事任务农具Service接口
 * 
 * @author 杨晓辉
 * @date 2023-05-25
 */
public interface IFmsTaskmachineService 
{
    /**
     * 查询农事任务农具
     * 
     * @param taskmachId 农事任务农具主键
     * @return 农事任务农具
     */
    public FmsTaskmachine selectFmsTaskmachineByTaskmachId(String taskmachId);

    /**
     * 查询农事任务农具列表
     * 
     * @param fmsTaskmachine 农事任务农具
     * @return 农事任务农具集合
     */
    public List<FmsTaskmachine> selectFmsTaskmachineList(FmsTaskmachine fmsTaskmachine);
    /**
     * 查询农事任务农具列表
     *
     * @param taskrcdId 记录标识
     * @return 农事任务农具集合
     */
    public List<FmsTaskmachineResVo> selectFmsTaskmachineByRcdId(String taskrcdId);

    public List<FmsTaskmachineResVo> selectFmsTaskmachineStat(FmsTaskListReqVo reqVo);
    /**
     * 新增农事任务农具
     * 
     * @param fmsTaskmachine 农事任务农具
     * @return 结果
     */
    public int insertFmsTaskmachine(FmsTaskmachine fmsTaskmachine);

    /**
     * 修改农事任务农具
     * 
     * @param fmsTaskmachine 农事任务农具
     * @return 结果
     */
    public int updateFmsTaskmachine(FmsTaskmachine fmsTaskmachine);

    /**
     * 批量删除农事任务农具
     * 
     * @param taskmachIds 需要删除的农事任务农具主键集合
     * @return 结果
     */
    public int deleteFmsTaskmachineByTaskmachIds(String[] taskmachIds);

    /**
     * 删除农事任务农具信息
     * 
     * @param taskmachId 农事任务农具主键
     * @return 结果
     */
    public int deleteFmsTaskmachineByTaskmachId(String taskmachId);
}
